summaryrefslogtreecommitdiffstats
path: root/ksysv/ksvpathconfig.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'ksysv/ksvpathconfig.cpp')
-rw-r--r--ksysv/ksvpathconfig.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/ksysv/ksvpathconfig.cpp b/ksysv/ksvpathconfig.cpp
index cba5b77..f7e5f52 100644
--- a/ksysv/ksvpathconfig.cpp
+++ b/ksysv/ksvpathconfig.cpp
@@ -29,11 +29,11 @@
#include <kfiledialog.h>
/*
* Constructs a KSVPathConfig which is a child of 'parent', with the
* name 'name' and widget flags set to 'f'
*/
-KSVPathConfig::KSVPathConfig( TQWidget* parent, const char* name, WFlags fl )
- : PathConfiguration( parent, name, fl )
+KSVPathConfig::KSVPathConfig( TQWidget* tqparent, const char* name, WFlags fl )
+ : PathConfiguration( tqparent, name, fl )
{
mSpacer->setFixedHeight (KDialog::spacingHint());
}
@@ -43,7 +43,7 @@ KSVPathConfig::KSVPathConfig( TQWidget* parent, const char* name, WFlags fl )
*/
KSVPathConfig::~KSVPathConfig()
{
- // no need to delete child widgets, Qt does it all for us
+ // no need to delete child widgets, TQt does it all for us
}
void KSVPathConfig::browseServices()
@@ -29,11 +29,11 @@
#include <kfiledialog.h>
/*
- * Constructs a KSVPathConfig which is a child of 'parent', with the
+ * Constructs a KSVPathConfig which is a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'
*/